{
  description = "purr - a web application for generating and sharing secrets ";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs";
    flake-utils.url = "github:numtide/flake-utils";
    nix2container.url = "github:nlewo/nix2container";
  };

  outputs = { self, nixpkgs, flake-utils, nix2container }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        pkgs              = nixpkgs.legacyPackages.${system};
        packageName       = "purr";
        dockerPackageName = "${packageName}-docker";

        nix2containerPkgs = nix2container.packages.x86_64-linux;

        haskellPackages = pkgs.haskellPackages;

        enableSharedExecutables = false;
        enableSharedLibraries = false;

        purr = pkgs.haskell.lib.justStaticExecutables self.packages.${system}.default;

      in {

        packages.${packageName} =
          haskellPackages.callCabal2nix packageName self rec {};

        packages.default = self.packages.${system}.${packageName};
        defaultPackage = self.packages.${system}.default;

        devShells.default = pkgs.mkShell {
          buildInputs = with pkgs; [
            ghcid
            cabal-install
          ];
          inputsFrom = map (__getAttr "env") (__attrValues self.packages.${system});
        };

        devShell = self.devShells.${system}.default;

        packages.${dockerPackageName} = pkgs.dockerTools.buildImage {
          name = "purr";

          copyToRoot = pkgs.buildEnv {
            name = "image-root";
            paths = [ purr ];
            pathsToLink = [ "/bin" ];
          };
          tag = "latest";
          config = {
            Cmd = [
              "/bin/Purr"
            ];
            ExposedPorts = {
              "3000/tcp" = {};
            };
            extraCommands = ''
            '';
          };
        };
      });
}
